;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "package-lint" "20260427.1106"
  "A linting library for elisp package authors."
  '((emacs     "24.4")
    (let-alist "1.0.6"))
  :url "https://github.com/purcell/package-lint"
  :commit "7e2dfcf99011fa82d92baba973841db717657964"
  :revdesc "7e2dfcf99011"
  :keywords '("lisp")
  :authors '(("Steve Purcell" . "steve@sanityinc.com")
             ("Fanael Linithien" . "fanael4@gmail.com"))
  :maintainers '(("Steve Purcell" . "steve@sanityinc.com")
                 ("Fanael Linithien" . "fanael4@gmail.com")))
